View source: R/magic_partial.R
| magic.partial | R Documentation |
This function produces m (or m-set) founder combinations and crosses for
8 or more founders. For balanced=TRUE, n is restricted to 8 or 16.
For balanced=FALSE, n is limited to 8, 16, 32, 64, 128.
Please refer to the section on partial MAGIC design in the
vignette
for more information on the accepted m values for each n.
magic.partial(n, m, balanced, n.try = 1000, inbred = TRUE)
n |
number of founders. |
m |
number of funnels ( |
balanced |
logical indicator of whether balanced partial design is chosen or ignored. |
n.try |
number of attempts to find balanced partial design (ignored if |
inbred |
logical indicator of whether the founders are inbred. |
an object of "cross.info" class, i.e. a list of
founder combinations (fcomb) and crossing plans (xplan).
mpop <- magic.partial(n=8, m=1, balanced=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.