| magic.plot | R Documentation |
This function takes a list of outputs from magic.eval and compares the MAGIC designs
via various plots. There are two plot display options available: "interval" highlights
the recombinations within the previously specified hap.int argument, while "whole"
shows the distribution of founder genomes in the RILs.
magic.plot(
input,
display = c("interval", "whole"),
fpair = NULL,
chr.names = NULL,
annotate = TRUE,
design.names = NULL
)
input |
a list of one or more outputs from magic.eval. |
display |
a character indicator of whether |
fpair |
a matrix of two columns of founder pairs (ignored if |
chr.names |
a vector of chromosome names (optional). |
annotate |
a logical indicator of whether to annotate subplot C if |
design.names |
a vector of design names (optional). |
multi-section plots.
magic.summary
mpop1 <- magic.eval(n=8, m=1, reps=c(1,1,4), self=c(0,0,3), balanced=TRUE, n.sim=10) mpop2 <- magic.eval(n=8, m=7, reps=c(1,1,4), self=c(0,0,3), balanced=FALSE, n.sim=10) magic.plot(input=list(mpop1, mpop2), display="interval")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.